@@ -6,11 +6,11 @@ from fief.dependencies.admin_api_key import (
     get_paginated_api_keys,
 )
 from fief.dependencies.admin_session import get_admin_session_token
-from fief.dependencies.current_account import get_current_account
+from fief.dependencies.current_workspace import get_current_workspace
 from fief.dependencies.main_managers import get_admin_api_key_manager
 from fief.dependencies.pagination import PaginatedObjects
 from fief.managers import AdminAPIKeyManager
-from fief.models import Account, AdminAPIKey
+from fief.models import AdminAPIKey, Workspace
 from fief.schemas.generics import PaginatedResults
 
 router = APIRouter()
@@ -37,10 +37,10 @@ async def list_api_keys(
 )
 async def create_api_key(
     create_api_key: schemas.admin_api_key.AdminAPIKeyCreate,
-    current_account: Account = Depends(get_current_account),
+    current_workspace: Workspace = Depends(get_current_workspace),
     manager: AdminAPIKeyManager = Depends(get_admin_api_key_manager),
 ) -> schemas.admin_api_key.AdminAPIKeyCreateResponse:
-    api_key = AdminAPIKey(**create_api_key.dict(), account_id=current_account.id)
+    api_key = AdminAPIKey(**create_api_key.dict(), workspace_id=current_workspace.id)
     api_key = await manager.create(api_key)
 
     return schemas.admin_api_key.AdminAPIKeyCreateResponse.from_orm(api_key)
